@@ -11,7 +11,7 @@ class StatusInformation(SnmpV3Error):
     def __init__(self, **kwargs):
         SnmpV3Error.__init__(self)
         self.__errorIndication = kwargs
-        debug.logger & (debug.flagDsp|debug.flagMP|debug.flagSM) and debug.logger('StatusInformation: %s' % kwargs)
+        debug.logger & (debug.flagDsp|debug.flagMP|debug.flagSM|debug.flagACL) and debug.logger('StatusInformation: %s' % kwargs)
     def __str__(self): return str(self.__errorIndication)
     def __getitem__(self, key): return self.__errorIndication[key]
     def has_key(self, key): return self.__errorIndication.has_key(key)
